package com.ruoyi.ibs.list.service.impl;

import com.ruoyi.ibs.list.domain.CustDeptUserGrid;
import com.ruoyi.ibs.list.mapper.CustDeptUserGridMapper;
import com.ruoyi.ibs.list.service.ICustDeptUserGridService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 客户与机构，用户，网格关联关系（暂时存放假的管户关系）Service业务层处理
 *
 * @author ruoyi
 * @date 2024-09-24
 */
@Service
public class CustDeptUserGridServiceImpl implements ICustDeptUserGridService {
    @Autowired
    private CustDeptUserGridMapper custDeptUserGridMapper;

    /**
     * 查询客户与机构，用户，网格关联关系（暂时存放假的管户关系）
     *
     * @param id 客户与机构，用户，网格关联关系（暂时存放假的管户关系）主键
     * @return 客户与机构，用户，网格关联关系（暂时存放假的管户关系）
     */
    @Override
    public CustDeptUserGrid selectCustDeptUserGridById(Long id) {
        return custDeptUserGridMapper.selectCustDeptUserGridById(id);
    }

    /**
     * 查询客户与机构，用户，网格关联关系（暂时存放假的管户关系）列表
     *
     * @param custDeptUserGrid 客户与机构，用户，网格关联关系（暂时存放假的管户关系）
     * @return 客户与机构，用户，网格关联关系（暂时存放假的管户关系）
     */
    @Override
    public List<CustDeptUserGrid> selectCustDeptUserGridList(CustDeptUserGrid custDeptUserGrid) {
        return custDeptUserGridMapper.selectCustDeptUserGridList(custDeptUserGrid);
    }

    /**
     * 新增客户与机构，用户，网格关联关系（暂时存放假的管户关系）
     *
     * @param custDeptUserGrid 客户与机构，用户，网格关联关系（暂时存放假的管户关系）
     * @return 结果
     */
    @Override
    public int insertCustDeptUserGrid(CustDeptUserGrid custDeptUserGrid) {
        return custDeptUserGridMapper.insertCustDeptUserGrid(custDeptUserGrid);
    }

    /**
     * 修改客户与机构，用户，网格关联关系（暂时存放假的管户关系）
     *
     * @param custDeptUserGrid 客户与机构，用户，网格关联关系（暂时存放假的管户关系）
     * @return 结果
     */
    @Override
    public int updateCustDeptUserGrid(CustDeptUserGrid custDeptUserGrid) {
        return custDeptUserGridMapper.updateCustDeptUserGrid(custDeptUserGrid);
    }

    /**
     * 批量删除客户与机构，用户，网格关联关系（暂时存放假的管户关系）
     *
     * @param ids 需要删除的客户与机构，用户，网格关联关系（暂时存放假的管户关系）主键
     * @return 结果
     */
    @Override
    public int deleteCustDeptUserGridByIds(Long[] ids) {
        return custDeptUserGridMapper.deleteCustDeptUserGridByIds(ids);
    }

    /**
     * 删除客户与机构，用户，网格关联关系（暂时存放假的管户关系）信息
     *
     * @param id 客户与机构，用户，网格关联关系（暂时存放假的管户关系）主键
     * @return 结果
     */
    @Override
    public int deleteCustDeptUserGridById(Long id) {
        return custDeptUserGridMapper.deleteCustDeptUserGridById(id);
    }
}
